@@ -6,19 +6,19 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.5.1'
-__release__ = 20230106
-__all__ = ['Unit']
+__version__ = '0.5.4'
+__release__ = 20230112
+__all__ = ['Unit', 'is_Unit']
 
 from unyts.errors import WrongUnitsError, WrongValueError, NoConversionFoundError
 from unyts.operations import unit_product, unit_division, unit_base_power
 from unyts.converter import convert, convertible
 from numbers import Number
-from typing import Union
+
 
 try:
     import numpy as np
-    from numpy import ndarray
+    from numpy import ndarray, int64, float64, int32, float32
     _numpy_ = True
 except ModuleNotFoundError:
     _numpy_ = False
@@ -29,20 +29,22 @@ except ModuleNotFoundError:
     _pandas_ = False
 
 if _numpy_ and _pandas_:
-    numeric = Union[int, float, complex, ndarray, Series, DataFrame]
-    array_like = tuple([ndarray, Series, DataFrame])
+    number = (int, float, complex, int32, int64, float32, float64)
+    numeric = (int, float, complex, int32, int64, float32, float64, ndarray, Series, DataFrame)
+    array_like = (ndarray, Series, DataFrame)
 elif _numpy_:
-    numeric = Union[int, float, complex, ndarray]
-    array_like = tuple([ndarray])
+    number = (int, float, complex, int32, int64, float32, float64)
+    numeric = (int, float, complex, ndarray, int32, int64, float32, float64)
+    array_like = (ndarray,)
 elif _pandas_:
-    numeric = Union[int, float, complex, Series, DataFrame]
-    array_like = tuple([Series, DataFrame])
+    number = (int, float, complex)
+    numeric = (int, float, complex, Series, DataFrame)
+    array_like = (Series, DataFrame)
 else:
-    numeric = Union[int, float, complex]
+    number = (int, float, complex)
+    numeric = (int, float, complex)
     array_like = tuple()
 
-number = Union[int, float, complex]
-
 
 class Unit(object):
     """
@@ -84,7 +86,7 @@ class Unit(object):
         return self.convert(new_unit)
 
     def __neg__(self):
-        return self.kind(self.value * -1, self.unit)
+        return self.kind(self.value.__neg__(), self.unit)
 
     def __bool__(self):
         from .units.custom import UserUnits
@@ -127,8 +129,12 @@ class Unit(object):
             return tuple(result) if flag else other + (self,)
         elif self.kind is Percentage:
             return self.kind((self.value + other) * 100, self.unit)
-        else:
+        elif type(other) in numeric:
             return self.kind(self.value + other, self.unit)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__radd__(self)
+        else:
+            raise NotImplementedError("Addition of Unit and " + type(other) + " not implemented.")
 
     def __radd__(self, other):
         return self.__add__(other)
@@ -163,8 +169,12 @@ class Unit(object):
             return tuple(result)
         elif self.kind is Percentage:
             return self.kind(self.value * other * 100, self.unit)
-        else:
+        elif type(other) in numeric:
             return self.kind(self.value * other, self.unit)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__rmul__(self)
+        else:
+            raise NotImplementedError("Product of Unit and " + type(other) + " not implemented.")
 
     def __rmul__(self, other):
         return self.__mul__(other)
@@ -193,18 +203,21 @@ class Unit(object):
             for each in other:
                 result += [self ** each]
             return tuple(result)
-        else:
-            if self.kind is Percentage:
-                return self.kind((self.value ** other) * 100, self.unit)
+        elif self.kind is Percentage:
+            return self.kind((self.value ** other) * 100, self.unit)
+        elif type(other) in numeric:
+            pow_units = unit_base_power(self.unit)[1] * other
+            if pow_units == 0:
+                pow_units = 'Dimensionless'
+            elif pow_units == 1:
+                pow_units = unit_base_power(self.unit)[0]
             else:
-                pow_units = unit_base_power(self.unit)[1] * other
-                if pow_units == 0:
-                    pow_units = 'Dimensionless'
-                elif pow_units == 1:
-                    pow_units = unit_base_power(self.unit)[0]
-                else:
-                    pow_units = unit_base_power(self.unit)[0] + str(pow_units)
-                return units(self.value ** other, pow_units)
+                pow_units = unit_base_power(self.unit)[0] + str(pow_units)
+            return units(self.value ** other, pow_units)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__rpow__(self)
+        else:
+            raise NotImplementedError("Power of Unit to " + type(other) + " not implemented.")
 
     def __rpow__(self, other):
         from .units.unitless import Dimensionless, Percentage
@@ -248,8 +261,12 @@ class Unit(object):
             return tuple(result) if flag else other + (self,)
         elif self.kind is Percentage:
             return self.kind((self.value - other) * 100, self.unit)
-        else:
+        elif type(other) in numeric:
             return self.kind(self.value - other, self.unit)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__rsub__(self)
+        else:
+            raise NotImplementedError("Subtraction of Unit and " + type(other) + " not implemented.")
 
     def __rsub__(self, other):
         return self.__neg__() + other
@@ -281,8 +298,12 @@ class Unit(object):
             return tuple(result)
         elif self.kind is Percentage:
             return self.kind(self.value / other * 100, self.unit)
-        else:
+        elif type(other) in numeric:
             return units(self.value / other, self.unit)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__rtruediv__(self)
+        else:
+            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
 
     def __rtruediv__(self, other):
         from .units.define import units
@@ -291,8 +312,10 @@ class Unit(object):
             return units(other / self.value * 100, self.unit)
         elif self.kind is Dimensionless:
             return units(other / self.value, self.unit)
-        else:
+        elif type(other) in numeric:
             return units(other / self.value, self.unit + '-1')
+        else:
+            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
 
     def __floordiv__(self, other):
         from .units.unitless import Dimensionless, Percentage
@@ -321,8 +344,12 @@ class Unit(object):
             return tuple(result)
         elif self.kind is Percentage:
             return self.kind(self.value // other * 100, self.unit)
-        else:
+        elif type(other) in numeric:
             return self.kind(self.value // other, self.unit)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__rtruediv__(self)
+        else:
+            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
 
     def __rfloordiv__(self, other):
         from .units.define import units
@@ -331,8 +358,10 @@ class Unit(object):
             return units(other // self.value * 100, self.unit)
         elif self.kind is Dimensionless:
             return units(other // self.value, self.unit)
-        else:
+        elif type(other) in numeric:
             return units(other // self.value, self.unit + '-1')
+        else:
+            raise NotImplementedError("Division of Unit by " + type(other) + " not implemented.")
 
     def __mod__(self, other):
         from .units.unitless import Dimensionless, Percentage
@@ -360,8 +389,12 @@ class Unit(object):
             return tuple(result)
         elif self.kind is Percentage:
             return self.kind(self.value % other * 100, self.unit)
-        else:
+        elif type(other) in numeric:
             return self.kind(self.value % other, self.unit)
+        elif hasattr(other, '_identity_') and other._identity_ in ('SimSeries', 'SimDataFrame'):
+            return other.__rtruediv__(self)
+        else:
+            raise NotImplementedError("Module of Unit when divided by " + type(other) + " not implemented.")
 
     def __lt__(self, other) -> bool:
         if type(self) == type(other):
@@ -474,9 +507,20 @@ class Unit(object):
     def get_unit(self):
         return self.unit
 
+    def get_units(self):
+        return self.get_unit()
+
+    @property
+    def units(self):
+        return self.unit
+
     def get_value(self):
         return self.value
 
+    @property
+    def values(self):
+        return self.value
+
     def check_value(self, value):
         if type(value) in (list, tuple):
             try:
@@ -500,3 +544,7 @@ class Unit(object):
             return units
         else:
             raise WrongUnitsError("'" + str(units) + "' for '" + str(self.name) + "'")
+
+
+def is_Unit(obj) -> bool:
+    return isinstance(obj, Unit)
