@@ -6,8 +6,8 @@ Created on Sat Oct 24 14:34:59 2020
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
 
-__version__ = '0.4.9'
-__release__ = 20221231
+__version__ = '0.5.2'
+__release__ = 20230107
 __all__ = ['Length', 'Area', 'Volume']
 
 from unyts.dictionaries import dictionary
@@ -18,7 +18,7 @@ from unyts.helpers.common_classes import unit_or_str, numeric
 class Length(Unit):
     classUnits = dictionary['Length']
 
-    def __init__(self, value: numeric, units: unit_or_str) -> Unit:
+    def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'length'
         self.kind = Length
         self.value = self.check_value(value)
@@ -28,7 +28,7 @@ class Length(Unit):
 class Area(Unit):
     classUnits = dictionary['Area']
 
-    def __init__(self, value: numeric, units: unit_or_str) -> Unit:
+    def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'area'
         self.kind = Area
         self.value = self.check_value(value)
@@ -38,7 +38,7 @@ class Area(Unit):
 class Volume(Unit):
     classUnits = dictionary['Volume']
 
-    def __init__(self, value: numeric, units: unit_or_str) -> Unit:
+    def __init__(self, value: numeric, units: unit_or_str):
         self.name = 'volume'
         self.kind = Volume
         self.value = self.check_value(value)
